@@ -1,21 +1,7 @@
 /*
-    Copyright 2018 Pranav Gade <pranavgade20@gmail.com>
+    SPDX-FileCopyrightText: 2018 Pranav Gade <pranavgade20@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "usersettingtest.h"
@@ -27,7 +13,7 @@
 #include <QTest>
 
 #if !NM_CHECK_VERSION(1, 8, 0)
-#define NM_SETTING_USER_DATA            "data"
+#define NM_SETTING_USER_DATA "data"
 #endif
 
 void UserSettingTest::testSetting_data()
@@ -37,8 +23,7 @@ void UserSettingTest::testSetting_data()
     NMStringMap data;
     data.insert("dat", "abc");
 
-    QTest::newRow("setting1")
-            << data;              // data
+    QTest::newRow("setting1") << data; // data
 }
 
 void UserSettingTest::testSetting()
@@ -65,3 +50,5 @@ void UserSettingTest::testSetting()
 }
 
 QTEST_MAIN(UserSettingTest)
+
+#include "moc_usersettingtest.cpp"
