@@ -30,13 +30,6 @@ NetworkManager::OlpcMeshDevice::OlpcMeshDevice(const QString &path, QObject *par
     if (!initialProperties.isEmpty()) {
         d->propertiesChanged(initialProperties);
     }
-
-    QDBusConnection::systemBus().connect(NetworkManagerPrivate::DBUS_SERVICE,
-                                         d->uni,
-                                         NetworkManagerPrivate::FDO_DBUS_PROPERTIES,
-                                         QLatin1String("PropertiesChanged"),
-                                         d,
-                                         SLOT(dbusPropertiesChanged(QString, QVariantMap, QStringList)));
 }
 
 NetworkManager::OlpcMeshDevice::~OlpcMeshDevice()
@@ -83,3 +76,6 @@ void NetworkManager::OlpcMeshDevicePrivate::propertyChanged(const QString &prope
         DevicePrivate::propertyChanged(property, value);
     }
 }
+
+#include "moc_olpcmeshdevice.cpp"
+#include "moc_olpcmeshdevice_p.cpp"
